# [1.3.13](https://github.com/seriaati/yatta/compare/v1.3.12..v1.3.13) - 2025-08-14

## Bug Fixes

- **(deps)** Add imaging deps for mkdocs - ([d5dffab](https://github.com/seriaati/yatta/commit/d5dffabb1b9c44bfea940be6691981779672f736))
- Allow VoiceActor name to be optional - ([52f54ea](https://github.com/seriaati/yatta/commit/52f54ea32d255065a556f0302b09f1f284c56919))
- fix validation errors in Item, ItemDetail, and Changelog (#103) - ([d80837e](https://github.com/seriaati/yatta/commit/d80837e01dae8571a7013f86d24e2f108099db51))

## Continuous Integrations

- add pre-commit config - ([e8cd119](https://github.com/seriaati/yatta/commit/e8cd11991a76fb7663afabc0cef64b16699034fe))
- remove ruff-lint workflow - ([2318a4e](https://github.com/seriaati/yatta/commit/2318a4e34e5876d0e991101feedcf62edd7bb083))
- add auto release - ([801f3c8](https://github.com/seriaati/yatta/commit/801f3c8ca13c5fb5ca587d93b66931b4e1684baf))

## Documentation

- Add docs - ([4780ad3](https://github.com/seriaati/yatta/commit/4780ad3f85af1208725c5a6bf1a595182044c6cd))
- Update docs URL in readme - ([15507d6](https://github.com/seriaati/yatta/commit/15507d6b705f53cba89792e86a881fd2f8bfda27))
- Update documentation URLs - ([48a2d0d](https://github.com/seriaati/yatta/commit/48a2d0da3aafc657ab95ff9589c84b3193785336))
- Add social plugin - ([2bcb691](https://github.com/seriaati/yatta/commit/2bcb6917a5ba002d5606cf451488842d5a9d8339))
- Update mkdocs config - ([6d1e9f5](https://github.com/seriaati/yatta/commit/6d1e9f501a5a720529897d60ab6bd88ef9699ab5))

## Miscellaneous Chores

- **(deps)** lock file maintenance (#74) - ([2b919d8](https://github.com/seriaati/yatta/commit/2b919d82ad2eee008d8bb021531cb0f267b7ef01))
- **(deps)** lock file maintenance (#75) - ([2f7799c](https://github.com/seriaati/yatta/commit/2f7799c07df9fbe302758078e08468ce4ca718c9))
- **(deps)** lock file maintenance (#76) - ([38cb337](https://github.com/seriaati/yatta/commit/38cb3370002904b54c4952e5b1ce05cf5a49199d))
- **(deps)** lock file maintenance (#77) - ([92585b6](https://github.com/seriaati/yatta/commit/92585b6d43c478009e21e4db5aecf2b1d7c07e00))
- **(deps)** lock file maintenance (#78) - ([6682239](https://github.com/seriaati/yatta/commit/66822397850ad2117faee0c425c3a8693fcee29f))
- **(deps)** lock file maintenance (#79) - ([4d331df](https://github.com/seriaati/yatta/commit/4d331dfc1416823a375647ef59e531da815e0760))
- **(deps)** lock file maintenance (#80) - ([e302a80](https://github.com/seriaati/yatta/commit/e302a80de2dbcf64b482c4fbf6b2320d661b4727))
- **(deps)** update dependency python to 3.13 (#81) - ([9d55071](https://github.com/seriaati/yatta/commit/9d550710756bb6b86607a8e860bcb3bfd393492b))
- **(deps)** lock file maintenance (#82) - ([9effb26](https://github.com/seriaati/yatta/commit/9effb26a1a71e4aee002ea43e152cb9fcbd121d7))
- **(deps)** lock file maintenance (#83) - ([a7a0d45](https://github.com/seriaati/yatta/commit/a7a0d45161101df1814b52a217e139d71aa101f0))
- **(deps)** lock file maintenance (#84) - ([083a8e3](https://github.com/seriaati/yatta/commit/083a8e38ac459086a6081ee37fe4415ef1568b82))
- **(deps)** lock file maintenance (#85) - ([466a412](https://github.com/seriaati/yatta/commit/466a4123984fbe2cea95b10b3bf905f0ad0bae28))
- **(deps)** lock file maintenance (#86) - ([98b173e](https://github.com/seriaati/yatta/commit/98b173e265e2950198e179ee08ff3a16a912a060))
- **(deps)** lock file maintenance (#87) - ([f84d8d0](https://github.com/seriaati/yatta/commit/f84d8d08e1664bb14b6d821b868a1d4049b44729))
- **(deps)** update astral-sh/setup-uv action to v6 (#88) - ([41f8072](https://github.com/seriaati/yatta/commit/41f80720b7d8b5eff2fbda6166e06f167222a577))
- **(deps)** lock file maintenance (#89) - ([cba82e6](https://github.com/seriaati/yatta/commit/cba82e6b57928137cde9d1cb6f3829b786899b3b))
- **(deps)** lock file maintenance (#90) - ([3017c8f](https://github.com/seriaati/yatta/commit/3017c8fb6f4fa702fdd3468e94fef667534494ff))
- **(deps)** lock file maintenance (#91) - ([966cd5e](https://github.com/seriaati/yatta/commit/966cd5e0c40b4d602db5cfc8d5afa5bfc85b34e2))
- **(deps)** lock file maintenance (#92) - ([ca41c57](https://github.com/seriaati/yatta/commit/ca41c579739807c6ddacb0367d75ae2bb7f05080))
- **(deps)** lock file maintenance (#93) - ([f29c894](https://github.com/seriaati/yatta/commit/f29c894eccd7063469b1954dca635961fcc6c0e8))
- **(deps)** lock file maintenance (#94) - ([103bac1](https://github.com/seriaati/yatta/commit/103bac1efca2c08bcc3ea781e0e8aec260ae7278))
- **(deps)** lock file maintenance (#95) - ([dacc87c](https://github.com/seriaati/yatta/commit/dacc87c24ab8a1a52f11fb95ee848cc313973aba))
- **(deps)** lock file maintenance (#96) - ([7ee5fdb](https://github.com/seriaati/yatta/commit/7ee5fdb761ad9ecf56d81bc1a9842a1264c9c5f8))
- **(deps)** lock file maintenance (#97) - ([e66281d](https://github.com/seriaati/yatta/commit/e66281d1a72b91bdfe76363e12b1fc948dfe8999))
- **(deps)** lock file maintenance (#98) - ([62780a6](https://github.com/seriaati/yatta/commit/62780a61377ac993f6fdac37df4820e70a8fd3df))
- **(deps)** lock file maintenance (#99) - ([cf82138](https://github.com/seriaati/yatta/commit/cf821384b22d65659d88199dc1436be77450a335))
- **(deps)** lock file maintenance (#100) - ([c1ee9c1](https://github.com/seriaati/yatta/commit/c1ee9c11e807e7140d6f15ce7111e988d07f4665))
- **(deps)** lock file maintenance (#101) - ([2f6f0da](https://github.com/seriaati/yatta/commit/2f6f0dad9806900248f564078add7668388fb457))
- **(deps)** update actions/checkout action to v5 (#102) - ([d8de73b](https://github.com/seriaati/yatta/commit/d8de73b24ab7b22519ca461dcfb2beafd5f51ad4))
- Add docs URL to project.urls - ([236db26](https://github.com/seriaati/yatta/commit/236db26a0f30dde43c4dda66be28fc47430a1786))

<!-- generated by git-cliff -->
